#[non_exhaustive]pub struct AddedItem {
pub id: Id,
pub index: u64,
}Expand description
One entry in the added array of a QueryChangesResult: a typed
(index, id) pair.
One entry in the added list of a /queryChanges response (RFC 8620 5.6).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: IdThe id of the newly-added object.
index: u64Its 0-based position in the result list after applying all changes.
Implementations